dupin.data
----------

.. rubric:: Overview

.. py:currentmodule:: dupin.data

.. autosummary::
    :nosignatures:

    make_generator
    map_
    reduce_

.. rubric:: Details

.. automodule:: dupin.data
    :members: make_generator, map_, reduce_

.. rubric:: Modules

.. toctree::
   :maxdepth: 1

   module-data-aggregate
   module-data-base
   module-data-freud
   module-data-logging
   module-data-map
   module-data-reduce
   module-data-spatial
